pub struct ToolsBuilder { /* private fields */ }Available on non-
target_family=wasm only.Expand description
Builder for the built-in tool selection.
Implementations
Sourceimpl ToolsBuilder
impl ToolsBuilder
Sourcepub const fn without_defaults(self) -> Self
pub const fn without_defaults(self) -> Self
Starts from an empty built-in tool set.
Sourcepub const fn workspace(self, enabled: bool) -> Self
pub const fn workspace(self, enabled: bool) -> Self
Enables or disables the standard command, patch, plan, and file tools.
Sourcepub const fn web_search(self, enabled: bool) -> Self
pub const fn web_search(self, enabled: bool) -> Self
Enables or disables the built-in direct web-search tool.
Sourcepub const fn image_generation(self, enabled: bool) -> Self
pub const fn image_generation(self, enabled: bool) -> Self
Enables or disables the built-in image-generation tool.
Sourcepub fn working_directory(self, directory: impl Into<Arc<str>>) -> Self
pub fn working_directory(self, directory: impl Into<Arc<str>>) -> Self
Overrides the default working directory described to the model.
Sourcepub fn default_shell(self, shell: impl Into<Arc<str>>) -> Self
pub fn default_shell(self, shell: impl Into<Arc<str>>) -> Self
Overrides the default shell described to the model.
Sourcepub fn process_environment<I, K, V>(self, variables: I) -> Self
pub fn process_environment<I, K, V>(self, variables: I) -> Self
Adds explicit environment overrides to workspace-tool child processes.
Overrides are scoped to commands spawned by this tool selection and do not mutate the embedding process. A later value for the same name wins.
Sourcepub fn remote_http_client(self, client: Client) -> Self
pub fn remote_http_client(self, client: Client) -> Self
Overrides the HTTP client used by in-process remote tools.
Sourcepub fn tool<T: Tool + 'static>(self, tool: T) -> Self
pub fn tool<T: Tool + 'static>(self, tool: T) -> Self
Adds a function or freeform tool to the runtime.
Sourcepub fn provider<P: DynamicToolProvider + 'static>(self, provider: P) -> Self
pub fn provider<P: DynamicToolProvider + 'static>(self, provider: P) -> Self
Adds a dynamic family of Code Mode tools.